@@ -1,7 +1,7 @@
 '''
 BLURB GOES HERE.
 
-Copyright (c) 2015 - 2020 Rob "N3X15" Nelson <nexisentertainment@gmail.com>
+Copyright (c) 2015 - 2021 Rob "N3X15" Nelson <nexisentertainment@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -23,11 +23,13 @@ SOFTWARE.
 
 '''
 import hashlib
-import yaml
 import os
 
 from pathlib import Path
 
+from ruamel.yaml import YAML
+yaml = YAML(typ='safe', pure=True)
+
 from buildtools import os_utils, utils
 from buildtools.bt_logging import log
 from buildtools.maestro.utils import callLambda
@@ -39,7 +41,7 @@ class BuildTarget(object):
     BT_LABEL = None
 
     #           YYYYMMDDhhmm
-    CACHE_VER = 201906171527
+    CACHE_VER = 202101160312
 
     CHECK_MTIMES = True
     CHECK_HASHES = True
@@ -88,7 +90,7 @@ class BuildTarget(object):
             log.info('<red>RM    </red> %s',filename)
             os.remove(filename)
 
-    def __failed(self):
+    def _set_failed(self):
         self.built = False
         log.warn('Cleaning build artifacts due to failure...')
         self.clean()
@@ -216,7 +218,7 @@ class BuildTarget(object):
         if os.path.isfile(self.getCacheFile()):
             try:
                 with open(self.getCacheFile(), 'r') as f:
-                    cachedata = list(yaml.load_all(f, Loader=yaml.Loader))
+                    cachedata = list(yaml.load_all(f))
                     if len(cachedata)==6 and cachedata[0] == self.CACHE_VER:
                         _, _CH, _TH, _LFT, _LFH, _CFG = cachedata
                         self.lastConfigHash=_CH
